@@ -4,7 +4,7 @@ use warnings;
 
 package Mxpress::PDF {
 	BEGIN {
-		our $VERSION = '0.19';
+		our $VERSION = '0.20';
 		our $AUTHORITY = 'cpan:LNATION';
 	};
 	use Zydeco;
@@ -12,7 +12,7 @@ package Mxpress::PDF {
 	use constant mm => 25.4 / 72;
 	use constant pt => 1;
 	class File (HashRef $args) {
-		my @plugins = (qw/font line box circle pie ellipse text title subtitle subsubtitle toc image form input textarea select annotation cover/, ($args->{plugins} ? @{$args->{plugins}} : ()));
+		my @plugins = (qw/font line box circle pie ellipse text title subtitle subsubtitle h1 h2 h3 h4 h5 h6 toc image form input textarea select annotation cover/, ($args->{plugins} ? @{$args->{plugins}} : ()));
 		for my $p (@plugins) {
 			my $meth = sprintf('_store_%s', $p);
 			has {$meth} (type => Object);
@@ -1215,7 +1215,7 @@ Mxpress::PDF - PDF
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
@@ -1410,6 +1410,42 @@ Returns a new Mxpress::PDF::Plugin::Text::Subsubtitle Object. This object aids w
 
 	my $subsubtitle = Mxpress::PDF->subsubtitle($file, %subsubtitle_args);
 
+=head2 h1
+
+Returns a new Mxpress::PDF::Plugin::Text::H1 Object. This object aids with writing 'heading' text to a pdf page.
+
+	my $h1 = Mxpress::PDF->h1($file, %h1_args);
+
+=head2 h2
+
+Returns a new Mxpress::PDF::Plugin::Text::H2 Object. This object aids with writing 'heading' text to a pdf page.
+
+	my $h1 = Mxpress::PDF->h2($file, %h2_args);
+
+=head2 h3
+
+Returns a new Mxpress::PDF::Plugin::Text::H3 Object. This object aids with writing 'heading' text to a pdf page.
+
+	my $h1 = Mxpress::PDF->h3($file, %h3_args);
+
+=head2 h4
+
+Returns a new Mxpress::PDF::Plugin::Text::H4 Object. This object aids with writing 'heading' text to a pdf page.
+
+	my $h1 = Mxpress::PDF->h2($file, %h4_args);
+
+=head2 h5
+
+Returns a new Mxpress::PDF::Plugin::Text::H5 Object. This object aids with writing 'heading' text to a pdf page.
+
+	my $h1 = Mxpress::PDF->h2($file, %h5_args);
+
+=head2 h6
+
+Returns a new Mxpress::PDF::Plugin::Text::H6 Object. This object aids with writing 'heading' text to a pdf page.
+
+	my $h1 = Mxpress::PDF->h2($file, %h6_args);
+
 =head2 toc
 
 Returns a new Mxpress::PDF::Plugin::TOC Object. This object is for managing a table of contents.
@@ -1578,6 +1614,42 @@ A Mxpress::PDF::Plugin::Subsubtitle Object
 
 	$file->subsubtitle->add;
 
+=head3 h1
+
+A Mxpress::PDF::Plugin::H1 Object.
+
+	$file->h1->add;
+
+=head3 h2
+
+A Mxpress::PDF::Plugin::H2 Object.
+
+	$file->h2->add;
+
+=head3 h3
+
+A Mxpress::PDF::Plugin::H3 Object.
+
+	$file->h3->add;
+
+=head3 h4
+
+A Mxpress::PDF::Plugin::H4 Object.
+
+	$file->h4->add;
+
+=head3 h5
+
+A Mxpress::PDF::Plugin::H5 Object.
+
+	$file->h5->add;
+
+=head3 h6
+
+A Mxpress::PDF::Plugin::H6 Object.
+
+	$file->h6->add;
+
 =head3 text
 
 A Mxpress::PDF::Plugin::Text Object
@@ -2498,6 +2570,102 @@ or when calling the objects add method.
 		%subsubtitle_attrs
 	);
 
+=head1 H1
+
+Mxpress::PDF::Plugin::H1 extends Mxpress::PDF::Plugin::Text and is for aiding with adding headings to a Mxpress::PDF::Page.
+
+You can pass default attributes when instantiating the file object.
+
+	Mxpress::PDF->add_file($filename,
+		h1 => { %heading_attrs },
+	);
+
+or when calling the objects add method.
+
+	$file->h1->add(
+		%heading_attrs
+	);
+
+=head1 H2
+
+Mxpress::PDF::Plugin::H2 extends Mxpress::PDF::Plugin::Text and is for aiding with adding headings to a Mxpress::PDF::Page.
+
+You can pass default attributes when instantiating the file object.
+
+	Mxpress::PDF->add_file($filename,
+		h2 => { %heading_attrs },
+	);
+
+or when calling the objects add method.
+
+	$file->h2->add(
+		%heading_attrs
+	);
+
+=head1 H3
+
+Mxpress::PDF::Plugin::H3 extends Mxpress::PDF::Plugin::Text and is for aiding with adding headings to a Mxpress::PDF::Page.
+
+You can pass default attributes when instantiating the file object.
+
+	Mxpress::PDF->add_file($filename,
+		h3 => { %heading_attrs },
+	);
+
+or when calling the objects add method.
+
+	$file->h3->add(
+		%heading_attrs
+	);
+
+=head1 H4
+
+Mxpress::PDF::Plugin::H4 extends Mxpress::PDF::Plugin::Text and is for aiding with adding headings to a Mxpress::PDF::Page.
+
+You can pass default attributes when instantiating the file object.
+
+	Mxpress::PDF->add_file($filename,
+		h4 => { %heading_attrs },
+	);
+
+or when calling the objects add method.
+
+	$file->h4->add(
+		%heading_attrs
+	);
+
+=head1 H5
+
+Mxpress::PDF::Plugin::H5 extends Mxpress::PDF::Plugin::Text and is for aiding with adding headings to a Mxpress::PDF::Page.
+
+You can pass default attributes when instantiating the file object.
+
+	Mxpress::PDF->add_file($filename,
+		h5 => { %heading_attrs },
+	);
+
+or when calling the objects add method.
+
+	$file->h5->add(
+		%heading_attrs
+	);
+
+=head1 H6
+
+Mxpress::PDF::Plugin::H6 extends Mxpress::PDF::Plugin::Text and is for aiding with adding headings to a Mxpress::PDF::Page.
+
+You can pass default attributes when instantiating the file object.
+
+	Mxpress::PDF->add_file($filename,
+		h6 => { %heading_attrs },
+	);
+
+or when calling the objects add method.
+
+	$file->h6->add(
+		%heading_attrs
+	);
+
 =head1 TOC
 
 Mxpress::PDF::Plugin::TOC extends Mxpress::PDF::Plugin and is for managing a table of contents.
